==> eslint-plugin-jsx-a11y-1.0.2.tgz: package/lib/rules/onclick-has-role.js <==
/**
 * @fileoverview Enforce non-interactive elements with
 *  click handlers use role attribute.
 * @author Ethan Cohen
 */
'use strict';

var _isHiddenFromScreenReader = require('../util/isHiddenFromScreenReader');

var _isHiddenFromScreenReader2 = _interopRequireDefault(_isHiddenFromScreenReader);

var _isInteractiveElement = require('../util/isInteractiveElement');

var _isInteractiveElement2 = _interopRequireDefault(_isInteractiveElement);

var _getAttribute = require('../util/getAttribute');

var _getAttribute2 = _interopRequireDefault(_getAttribute);

var _getAttributeValue = require('../util/getAttributeValue');

var _getAttributeValue2 = _interopRequireDefault(_getAttributeValue);

var _getNodeType = require('../util/getNodeType');

var _getNodeType2 = _interopRequireDefault(_getNodeType);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

// ----------------------------------------------------------------------------
// Rule Definition
// ----------------------------------------------------------------------------

var errorMessage = 'Visible, non-interactive elements with click handlers must ' + 'have role attribute.';

module.exports = function (context) {
  return {
    JSXOpeningElement: function JSXOpeningElement(node) {
      var attributes = node.attributes;
      if ((0, _getAttribute2.default)(attributes, 'onclick') === undefined) {
        return;
      }

      var type = (0, _getNodeType2.default)(node);

      if ((0, _isHiddenFromScreenReader2.default)(type, attributes)) {
        return;
      } else if ((0, _isInteractiveElement2.default)(type, attributes)) {
        return;
      } else if ((0, _getAttributeValue2.default)((0, _getAttribute2.default)(attributes, 'role'))) {
        return;
      }

      // Visible, non-interactive elements require role attribute.
      context.report({
        node: node,
        message: errorMessage
      });
    }
  };
};

module.exports.schema = [{ type: 'object' }];

==> eslint-plugin-jsx-a11y-1.4.0.tgz: package/lib/rules/onclick-has-role.js <==
/**
 * @fileoverview Enforce non-interactive elements with
 *  click handlers use role attribute.
 * @author Ethan Cohen
 */
'use strict';

var _isHiddenFromScreenReader = require('../util/isHiddenFromScreenReader');

var _isHiddenFromScreenReader2 = _interopRequireDefault(_isHiddenFromScreenReader);

var _isInteractiveElement = require('../util/isInteractiveElement');

var _isInteractiveElement2 = _interopRequireDefault(_isInteractiveElement);

var _jsxAstUtils = require('jsx-ast-utils');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

// ----------------------------------------------------------------------------
// Rule Definition
// ----------------------------------------------------------------------------

var errorMessage = 'Visible, non-interactive elements with click handlers must ' + 'have role attribute.';

module.exports = function (context) {
  return {
    JSXOpeningElement: function JSXOpeningElement(node) {
      var attributes = node.attributes;
      if ((0, _jsxAstUtils.getProp)(attributes, 'onclick') === undefined) {
        return;
      }

      var type = (0, _jsxAstUtils.elementType)(node);

      if ((0, _isHiddenFromScreenReader2.default)(type, attributes)) {
        return;
      } else if ((0, _isInteractiveElement2.default)(type, attributes)) {
        return;
      } else if ((0, _jsxAstUtils.getPropValue)((0, _jsxAstUtils.getProp)(attributes, 'role'))) {
        return;
      }

      // Visible, non-interactive elements require role attribute.
      context.report({
        node: node,
        message: errorMessage
      });
    }
  };
};

module.exports.schema = [{ type: 'object' }];
